Learn R Programming

DEET (version 1.0.11)

DEET_data_download: DEET_data_download

Description

Function to automatically download the files within the DEET database that are required for the DEET_enrich and DEET_feature_extractfunctions.

Usage

DEET_data_download(x = "enrich")

Value

Named list with the neccesary data required to input into DEET_feature_extract or DEET_enrich. The metadata within DEET can also be downloaded.

  • feature_matrix - A gene by comparison matrix populated with the log2FC of gene expression for all genes, regardless of DE status.

  • metadata - a comparison - by - explanatory piece of data dataframe providing important details to contextualize each study. For every pairwise comparison, the study name, source (SRA, TCGA, GTEx and SRA-manual), description from the DRA compendium, the number of samples (total, up-condition, and down-condition), samples (total ,up-condition, down-condition), tissue (including tumour from TCGA), number of DEs (total, up-condition, down-condition), age (mean +- sd), sex, top 15 DEGs - up, top 15 DEGs - down, top 5 enriched pathways, and top 5 enriched TFs. PMID are also available for studies selected from SRA. Lastly, each pairwise comparison was given an overall category based on those decided in Crow et al., 2019.

  • DEET_enrich - A named list of seven objects containing the data frames summarizing the DEGs from comparisons within DEET, GMT objects of comparisons within DEET for enrichment through ActivePathways, GMT objects for basic pathway and TF enrichment, and a dataframe for the metadata of each study. For more detail on each element of the list, please consult the vignette or "?DEET_example_data", as it is a subset of this object

Arguments

x

categorical variable containing options "ALL", "enrich", "metadata" or "feature_matrix".

Author

Dustin Sokolowski, Jedid Ahn

References

Engebretsen, S., & Bohlin, J. (2019). Statistical predictions with glmnet. Clinical epigenetics, 11(1), 1-3.

Examples

Run this code
# \donttest{

# Download the metadata. Downloading other
# files within DEET are larger and take
# a bit more time.
downloaded <- DEET_data_download(x = "metadata")

# extract metadata from the list
metadata <- downloaded[["metadata"]]

# }

Run the code above in your browser using DataLab