Learn R Programming

DEET (version 1.0.11)

DEET_enrich: DEET_enrich

Description

Core function of DEET where an input weighted human gene list will be queried to DEETs library of studies.

Usage

DEET_enrich(
  DEG_list,
  DEET_dataset,
  ordered = FALSE,
  background = NULL,
  abs_cor = FALSE
)

Value

Named list where each element contains 6 objects. Each object will contain the results (enrichment or correlation) and corresponding metadata.

  • AP_INPUT_BP_output - Enriched BPs of input gene list.

  • AP_INPUT_TF_output - Enriched TFs of input gene list.

  • AP_DEET_DE_output - Enrichment of input gene list on DEETs studies.

  • AP_DEET_BP_output - Enrichment of BPs of input gene list on DEETs BPs of studies.

  • AP_DEET_TF_output - Enrichment of TFs of input gene list on DEETs TFs of studies.

  • DE_correlations - Correlation values of input gene list to DEETs studies (both Pearson and Spearman).

Arguments

DEG_list

Data frame or matrix of gene symbols with corresponding padj and log2FC values (3 columns in total). Can also be a character vector of gene symbols only. colnames of genes: c("gene_symbol", "padj", "coef") The rownames of the dataframe are also the gene symbols.

DEET_dataset

The databank of the differential expression enrichment tool. Appropriate inputs here are "DEET_example_data" stored within DEET, the "DEET_combined.rda" file from the DEET stable repositoy found at X, and the DEET database developmental repository found at Y. The DEET_dataset is a named list where details of it's structure can be found ?DEET_example_data.

ordered

Boolean value specifying whether DEG_list is a character vector of gene symbols that is ordered. Default value is FALSE.

background

Character vector of human gene symbols showing all possible genes. Default value is NULL.

abs_cor

Boolean value that forces log2FC's in DEET to be their absolute value. Use when the directionality of the coefficient is unknown (or includes both up- down- directions). Default value is FALSE.

Author

Dustin Sokolowski, Jedid Ahn

References

Paczkowska M, Barenboim J, Sintupisut N, et al. Integrative pathway enrichment analysis of multivariate omics data. Nat Commun. 2020;11(1):735. doi:10.1038/s41467-019-13983-9

Examples

Run this code

data("example_DEET_enrich_input")
data("DEET_example_data")
DEET_out <- DEET_enrich(example_DEET_enrich_input, DEET_dataset = DEET_example_data)


Run the code above in your browser using DataLab