Altered version of the function of DEET where
an input weighted human gene list will be queried to DEETs
library of studies. This version does not include pathway
enrichments.
Named list where each element contains 2 objects. Each object will
contain the results (enrichment or correlation) and corresponding metadata.
AP_DEET_DE_output - Enrichment of input gene list on DEETs studies.
DE_correlations - Correlation values of input gene list to DEETs
studies (both Pearson and Spearman).
Arguments
DEG_list
Data frame or matrix of gene symbols with corresponding padj
and log2FC values (3 columns in total). Can also be a character vector of
gene symbols only. colnames of genes: c("gene_symbol", "padj", "coef")
The rownames of the dataframe are also the gene symbols.
DEET_dataset
The databank of the differential expression enrichment tool.
Appropriate inputs here are "DEET_example_data" stored within DEET, the "DEET_combined.rda" file
from the DEET stable repositoy found at X, and the DEET database developmental repository found at Y.
The DEET_dataset is a named list where details of it's structure can be found ?DEET_example_data.
Unlike in DEET_enrich, this dataset does not require the pathway-relevant elements
of the DEET_dataset list, namely "gmt_BP", or "gmt_TF" "DEET_gmt_BP", "DEET_gmt_TF".
ordered
Boolean value specifying whether DEG_list is a character
vector of gene symbols that is ordered. Default value is FALSE.
background
Character vector of human gene symbols showing all
possible genes. Default value is NULL.
Author
Dustin Sokolowski, Jedid Ahn
References
Paczkowska M, Barenboim J, Sintupisut N, et al. Integrative pathway
enrichment analysis of multivariate omics data. Nat Commun. 2020;11(1):735.
doi:10.1038/s41467-019-13983-9