The DEET_combined object but with the user-inputted
expression, log2FC, and FDR-adjusted p-value cutoffs. DEET_gmt_DE
is also updated to the new cutoffs.
Arguments
DEET_combined
The databank of the differential expression enrichment tool.
Appropriate inputs here are "DEET_example_data" stored within DEET, the "DEET_combined.rda" file
from the DEET stable repositoy found at X, and the DEET database developmental repository found at Y.
The DEET_dataset is a named list where details of it's structure can be found ?DEET_example_data.
redo_pathways_instructions
Boolean value specifying whether to print the instructions
required to update all pathway enrichments based on new DE cutoffs.