metadata - a comparison - by - explanatory piece of data dataframe
providing important details to contextualize each study.
For every pairwise comparison, the study name,
source (SRA, TCGA, GTEx and SRA-manual),
description from the DRA compendium,
the number of samples (total, up-condition,
and down-condition), samples (total ,up-condition, down-condition),
tissue (including tumour from TCGA),
number of DEs (total, up-condition, down-condition),
age (mean +- sd), sex, top 15 DEGs - up, top 15 DEGs - down,
top 5 enriched pathways, and top 5 enriched TFs.
PMID are also available for studies selected from SRA.
Lastly, each pairwise comparison was given an overall
category based on those decided in Crow et al., 2019.